@@ -2,6 +2,8 @@
 #include <string.h>
 using namespace Rcpp;
 
+#define MAX_LINE_WIDTH 10000	/* maximum line width */
+
 // This is a simple example of exporting a C++ function to R. You can
 // source this function into an R session using the Rcpp::sourceCpp 
 // function (or via the Source button on the editor toolbar). Learn
@@ -48,55 +50,55 @@ void gkmsvm_kernel(SEXP params){
       argv[i]=new char[5000]; 
     }
     
-    sprintf(argv[argc++], "gkmsvm_kernel"); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "gkmsvm_kernel"); 
     
-    sprintf(argv[argc++], "-l"); 
-    sprintf(argv[argc++], "%d", L); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "-l"); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "%d", L); 
     
-    sprintf(argv[argc++], "-k"); 
-    sprintf(argv[argc++], "%d", K); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "-k"); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "%d", K); 
     
-    sprintf(argv[argc++], "-d"); 
-    sprintf(argv[argc++], "%d", maxnmm); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "-d"); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "%d", maxnmm); 
     
-    sprintf(argv[argc++], "-m"); 
-    sprintf(argv[argc++], "%d", maxseqlen); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "-m"); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "%d", maxseqlen); 
     
-    sprintf(argv[argc++], "-n"); 
-    sprintf(argv[argc++], "%d", maxnumseq); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "-n"); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "%d", maxnumseq); 
     
-    sprintf(argv[argc++], "-t"); 
-    sprintf(argv[argc++], "%d", useTgkm); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "-t"); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "%d", useTgkm); 
     
-    sprintf(argv[argc++], "-a"); 
-    sprintf(argv[argc++], "%d", alg); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "-a"); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "%d", alg); 
     
 
-    sprintf(argv[argc++], "-M"); 
-    sprintf(argv[argc++], "%d", wildcardMismatchM); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "-M"); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "%d", wildcardMismatchM); 
     
-    sprintf(argv[argc++], "-L"); 
-    sprintf(argv[argc++], "%lf", wildcardLambda); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "-L"); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "%lf", wildcardLambda); 
     
     if(strcmp(alphabetFN.c_str(), "NULL")!=0){
-      sprintf(argv[argc++], "-A"); 
-      sprintf(argv[argc++], "%s", alphabetFN.c_str()); 
+      snprintf(argv[argc++],MAX_LINE_WIDTH, "-A"); 
+      snprintf(argv[argc++],MAX_LINE_WIDTH, "%s", alphabetFN.c_str()); 
     }
 
     if(addRC==false){
-      sprintf(argv[argc++], "-R"); 
+      snprintf(argv[argc++],MAX_LINE_WIDTH, "-R"); 
     }
     if(usePseudocnt==true){
-      sprintf(argv[argc++], "-p"); 
+      snprintf(argv[argc++],MAX_LINE_WIDTH, "-p"); 
     }
     
     if(OutputBinary==true){
-      sprintf(argv[argc++], "-b"); 
+      snprintf(argv[argc++],MAX_LINE_WIDTH, "-b"); 
     }
     
-    sprintf(argv[argc++], "%s", posfile.c_str()); 
-    sprintf(argv[argc++], "%s", negfile.c_str()); 
-    sprintf(argv[argc++], "%s", outfile.c_str()); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "%s", posfile.c_str()); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "%s", negfile.c_str()); 
+    snprintf(argv[argc++],MAX_LINE_WIDTH, "%s", outfile.c_str()); 
 
     
     
